using MongoDB.Driver;
using Todo.Core.Interfaces.Persistence;
using Todo.Persistence.Mongo.Repositories.Dtos;

namespace Todo.Persistence.Mongo.Repositories;

public class TodoRepository : ITodoRepository
{
    private readonly IMongoCollection<MongoTodo> _todosCollection;

    public TodoRepository(MongoDbConnectionHandler mongoDbConnectionHandler)
    {
        var database = mongoDbConnectionHandler.CreateDatabaseConnection();

        _todosCollection = database.GetCollection<MongoTodo>("todos");
    }

    public async Task<Core.Entities.Todo> CreateTodoAsync(string title, string projectName)
    {
        var todo = new MongoTodo() { Title = title, ProjectName = projectName };
        await _todosCollection.InsertOneAsync(todo);
        return new Core.Entities.Todo()
            { Id = todo.Id, Title = todo.Title, Status = false, Project = todo.ProjectName };
    }

    public async Task<IEnumerable<Core.Entities.Todo>> GetTodosAsync()
    {
        var todos = await _todosCollection.FindAsync(_ => true);
        return todos
            .ToEnumerable()
            .Select(t =>
                new Core.Entities.Todo() { Id = t.Id, Title = t.Title, Status = t.Status, Project = t.ProjectName });
    }

    public async Task UpdateTodoStatus(string todoId, bool todoStatus)
    {
        await _todosCollection
            .UpdateOneAsync(t => t.Id == todoId,
                Builders<MongoTodo>.Update.Set(t => t.Status, todoStatus));
    }

    public async Task<IEnumerable<Core.Entities.Todo>> GetNotDoneTodos()
    {
        var todos = await GetTodosAsync();
        return todos.Where(t => t.Status == false);
    }

    public async Task<Core.Entities.Todo> GetTodoByIdAsync(string todoId)
    {
        var todoCursor = await _todosCollection.FindAsync(f => f.Id == todoId);
        var todo = await todoCursor.FirstOrDefaultAsync();

        return new Core.Entities.Todo()
        {
            Id = todo.Id,
            Project = todo.ProjectName,
            Status = todo.Status,
            Title = todo.Title
        };
    }

    public async Task<Core.Entities.Todo> UpdateTodoAsync(Core.Entities.Todo todo)
    {
        var updatedTodo = await _todosCollection.FindOneAndReplaceAsync<MongoTodo>(f => f.Id == todo.Id, new MongoTodo()
        {
            Id = todo.Id,
            Status = todo.Status,
            Title = todo.Title,
            ProjectName = todo.Project
        });

        return new Core.Entities.Todo()
        {
            Id = updatedTodo.Id,
            Project = updatedTodo.ProjectName,
            Status = updatedTodo.Status,
            Title = updatedTodo.Title
        };
    }
}