import { FC, useState } from "react";
import { OutlinedButton } from "@src/components/common/buttons/outlinedButton";
import { PrimaryButton } from "@src/components/common/buttons/primaryButton";
import { TodoShortForm } from "@src/components/todos/collapsed/todoShortForm";

export const AddTodoForm: FC<{
  onAdd: (todoName: string, project: string) => void;
  onClose: () => void;
  project: string;
}> = ({ onAdd, onClose, ...props }) => {
  const [todoName, setTodoName] = useState("");
  const [todoDescription, setTodoDescription] = useState("");
  const [project, setProject] = useState(props.project);

  return (
    <form
      onSubmit={(e) => {
        e.preventDefault();
        onAdd(todoName, project);
        setTodoName("");
        setTodoDescription("");
      }}
    >
      <div className="py-2 space-y-3">
        <TodoShortForm
          project={project}
          onProjectChanged={(p) => setProject(p)}
          name={todoName}
          onNameChange={(e) => setTodoName(e.target.value)}
          description={todoDescription}
          onDescriptionChange={(e) => setTodoDescription(e.target.value)}
        />
        <div className="space-x-2">
          <PrimaryButton disabled={!todoName} type="submit">
            Add todo
          </PrimaryButton>
          <OutlinedButton onClick={onClose}>Cancel</OutlinedButton>
        </div>
      </div>
    </form>
  );
};
