import { PageHeading } from "@src/components/common/headings/pageHeading";
import { TodoList } from "@src/components/todos";
import { useSelectInboxTodos } from "@src/presentation/hooks/socketHooks";
import { ProjectsHeading } from "@src/components/common/headings/projectsHeading";
import { AddTodo } from "@src/components/todos/addTodo";

const groupByProjects = (arr) => {
  if (!arr) {
    return {};
  }
  const criteria = "project";

  return arr.reduce(function (acc, currentValue) {
    const currentValueElement = currentValue[criteria] || "inbox";

    if (!acc[currentValueElement]) {
      acc[currentValueElement] = [];
    }
    acc[currentValueElement].push(currentValue);
    return acc;
  }, {});
};

const HomePage = () => {
  const { todos, loading } = useSelectInboxTodos();
  const groupedTodos = groupByProjects(todos);
  const sections = Object.keys(groupedTodos)
    .filter((s) => s !== "inbox")
    .sort();

  return (
    <main className="py-8 px-14 space-y-6">
      <section className="space-y-8 mx-auto max-w-4xl">
        {groupedTodos["inbox"] && (
          <div className="space-y-2">
            <PageHeading title="Inbox" />
            <TodoList todos={groupedTodos["inbox"]} hideDone project={""} />
          </div>
        )}
        {sections &&
          sections.map((section) => (
            <div key={section} className="space-y-2">
              <ProjectsHeading title={section} />
              <TodoList
                todos={groupedTodos[section]}
                hideDone
                project={section}
              />
            </div>
          ))}
        {!loading && todos && todos.length === 0 && (
          <div className="space-y-4">
            <PageHeading title="You're done!" />
            <AddTodo project={""} />
          </div>
        )}
      </section>
    </main>
  );
};
export default HomePage;
